manipulation Package
====================

:mod:`manipulation` Package
---------------------------

.. automodule:: cobra.manipulation
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`delete` Module
--------------------

.. automodule:: cobra.manipulation.delete
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`modify` Module
--------------------

.. automodule:: cobra.manipulation.modify
    :members:
    :undoc-members:
    :show-inheritance:

